USE [master]
GO

/****** Object:  Database [Source]    Script Date: 09/08/2011 12:25:15 ******/
CREATE DATABASE [Source] ON  PRIMARY 
( NAME = N'Source', FILENAME = N'C:\Program Files\Microsoft SQL Server\MSSQL10_50.MSSQLSERVER\MSSQL\DATA\Source.mdf' , SIZE = 3072KB , MAXSIZE = UNLIMITED, FILEGROWTH = 1024KB )
 LOG ON 
( NAME = N'Source_log', FILENAME = N'C:\Program Files\Microsoft SQL Server\MSSQL10_50.MSSQLSERVER\MSSQL\DATA\Source_log.ldf' , SIZE = 1024KB , MAXSIZE = 2048GB , FILEGROWTH = 10%)
GO

ALTER DATABASE [Source] SET COMPATIBILITY_LEVEL = 100
GO

/****** Object:  Database [Destination]    Script Date: 09/08/2011 12:25:27 ******/
CREATE DATABASE [Destination] ON  PRIMARY 
( NAME = N'Target', FILENAME = N'C:\Program Files\Microsoft SQL Server\MSSQL10_50.MSSQLSERVER\MSSQL\DATA\Target.mdf' , SIZE = 3072KB , MAXSIZE = UNLIMITED, FILEGROWTH = 1024KB )
 LOG ON 
( NAME = N'Target_log', FILENAME = N'C:\Program Files\Microsoft SQL Server\MSSQL10_50.MSSQLSERVER\MSSQL\DATA\Target_log.ldf' , SIZE = 1024KB , MAXSIZE = 2048GB , FILEGROWTH = 10%)
GO

ALTER DATABASE [Destination] SET COMPATIBILITY_LEVEL = 100
GO

USE [master]
GO

/****** Object:  Database [Metadata]    Script Date: 09/08/2011 16:22:26 ******/
CREATE DATABASE [Metadata] ON  PRIMARY 
( NAME = N'Metadata', FILENAME = N'C:\Program Files\Microsoft SQL Server\MSSQL10_50.MSSQLSERVER\MSSQL\DATA\Metadata.mdf' , SIZE = 3072KB , MAXSIZE = UNLIMITED, FILEGROWTH = 1024KB )
 LOG ON 
( NAME = N'Metadata_log', FILENAME = N'C:\Program Files\Microsoft SQL Server\MSSQL10_50.MSSQLSERVER\MSSQL\DATA\Metadata_log.ldf' , SIZE = 1024KB , MAXSIZE = 2048GB , FILEGROWTH = 10%)
GO

ALTER DATABASE [Metadata] SET COMPATIBILITY_LEVEL = 100
GO


USE [Source]
GO

CREATE TABLE [dbo].[Person](
	[PersonID] [int] NOT NULL,
	[PersonForename] [nchar](30) NOT NULL,
	[PersonSurname] [nvarchar](50) NOT NULL,
	[DateOfBirth] [datetime2](7) NULL
) ON [PRIMARY]

GO

CREATE TABLE [dbo].[Orders](
	[OrderID] [int] NULL,
	[OrderRef] [nvarchar](50) NULL,
	[OrderPersonID] [int] NULL
) ON [PRIMARY]

GO

USE [Destination]
GO


CREATE TABLE [dbo].[Customer](
	[CustomerID] [int] NOT NULL,
	[CustomerName] [nvarchar](50) NULL,
	[CustomerSurname] [nvarchar](50) NULL,
	[DOB] [datetime] NULL
) ON [PRIMARY]

GO

CREATE TABLE [dbo].[CustomerOrder](
	[CustomerOrderID] [int] NOT NULL,
	[CustomerOrderReference] [nvarchar](50) NOT NULL,
	[CustomerID] [int] NOT NULL
) ON [PRIMARY]

GO

USE [Metadata]
GO

CREATE TABLE [dbo].[SourceTable](
	[SourceTableID] [int] NOT NULL,
	[SourceSchema] [nvarchar](50) NOT NULL,
	[SourceTableName] [nvarchar](50) NOT NULL
) ON [PRIMARY]

GO

CREATE TABLE [dbo].[DestinationTable](
	[DestinationTableID] [int] NOT NULL,
	[DestinationSchema] [nvarchar](50) NOT NULL,
	[DestinationTableName] [nvarchar](50) NOT NULL
) ON [PRIMARY]

GO

CREATE TABLE [dbo].[SourceColumn](
	[SourceColumnID] [int] NOT NULL,
	[SourceTableID] [int] NOT NULL,
	[SourceColumnName] [nvarchar](50) NOT NULL
) ON [PRIMARY]

GO

CREATE TABLE [dbo].[DestinationColumn](
	[DestinationColumnID] [int] NOT NULL,
	[DestinationTableID] [int] NOT NULL,
	[DestinationColumnName] [nvarchar](50) NOT NULL
) ON [PRIMARY]

GO

CREATE PROCEDURE [dbo].[hsp_GetSourceAndDestinationTable]
(
@ID INT
)

AS

BEGIN;

SET NOCOUNT ON;

DECLARE @SourceSchema SYSNAME;
DECLARE @SourceTableName SYSNAME;
DECLARE @DestinationSchema SYSNAME;
DECLARE @DestinationTableName SYSNAME;

SELECT 
		@SourceSchema = SourceSchema,
		@SourceTableName = SourceTableName
FROM	dbo.SourceTable	
WHERE	SourceTableID = @ID;

SELECT 
		@DestinationSchema = DestinationSchema,
		@DestinationTableName = DestinationTableName
FROM	dbo.DestinationTable	
WHERE	DestinationTableID = @ID;


SELECT @SourceSchema, @SourceTableName, @DestinationSchema, @DestinationTableName;

END;

GO

CREATE PROCEDURE [dbo].[hsp_GetSourceAndDestinationColumnMapping]
(
@ID	INT
)

AS

BEGIN;

DECLARE @Mapping NVARCHAR (4000) = '';
DECLARE @Cnt	 INT = 0;
DECLARE @Rid	 INT = 1;
DECLARE @Key	 INT = 0;
DECLARE @SourceColumnName SYSNAME;
DECLARE @DestinationColumnName SYSNAME;

SELECT @Cnt = COUNT(*)
FROM dbo.SourceColumn
WHERE SourceTableID = @ID;

--SELECT @Cnt;

WHILE @Rid <= @Cnt 

	BEGIN;
	
	--SELECT @Key;
	
	SELECT @Key = MIN(SourceColumnID)
	FROM dbo.SourceColumn
	WHERE SourceTableID = @ID
	AND	  SourceColumnID > @Key;
	
	SELECT @SourceColumnName = SourceColumnName
	FROM dbo.SourceColumn 
	WHERE SourceColumnID = @Key;

	SELECT @DestinationColumnName = DestinationColumnName
	FROM dbo.DestinationColumn 
	WHERE DestinationColumnID = @Key;
	
	SET @Mapping = @Mapping + @SourceColumnName + '=' + @DestinationColumnName + CASE WHEN @Rid <> @Cnt THEN '\r\n' ELSE '' END;
	
	SET @Rid += 1;
	
	END;
	
SELECT @Mapping;
	
END;	
GO

USE [Source]

GO

INSERT INTO dbo.Person 
VALUES 
(1, 'Fred', 'Smith', '01-01-1990'),
(2, 'Ginger', 'Smith', '01-06-1992'),
(3, 'George', 'Jones', '01-12-1992'),
(4, 'Jill', 'Jones', '01-03-1992');

GO

INSERT INTO dbo.Orders
VALUES (1, '00001', 1),
(2, '00002', 1),
(3, '00003', 2),
(4, '00004', 2);

GO

USE [Metadata]

GO

INSERT INTO [dbo].[SourceTable]
VALUES (1, 'dbo',  'Person'),
(2, 'dbo',  'Orders');

GO

INSERT INTO [dbo].[DestinationTable]
VALUES (1, 'dbo',  'Customer'),
(2, 'dbo',  'CustomerOrder');

GO


INSERT INTO [dbo].[SourceColumn]
VALUES 
	(1, 1, 'PersonID'),
	(2, 1, 'PersonForename'),
	(3, 1, 'PersonSurname'),
	(4, 1, 'DateOfBirth'),
	(5, 2, 'OrderID'),
	(6, 2, 'OrderRef'),
	(7, 2, 'OrderPersonID');
	
GO

INSERT INTO [dbo].[DestinationColumn]
VALUES 
	(1, 1, 'CustomerID'),
	(2, 1, 'CustomerName'),
	(3, 1, 'CustomerSurname'),
	(4, 1, 'DOB'),
	(5, 2, 'CustomerOrderID'),
	(6, 2, 'CustomerOrderReference'),
	(7, 2, 'CustomerID');

GO